pub struct StakeSystem {
pub stake_list: List,
pub delayed_unstake_cooling_down: u64,
pub stake_deposit_bump_seed: u8,
pub stake_withdraw_bump_seed: u8,
pub slots_for_stake_delta: u64,
pub last_stake_delta_epoch: u64,
pub min_stake: u64,
pub extra_stake_delta_runs: u32,
}Fields
stake_list: Listdelayed_unstake_cooling_down: u64stake_deposit_bump_seed: u8stake_withdraw_bump_seed: u8slots_for_stake_delta: u64set by admin, how much slots before the end of the epoch, stake-delta can start
last_stake_delta_epoch: u64Marks the start of stake-delta operations, meaning that if somebody starts a delayed-unstake ticket after this var is set with epoch_num the ticket will have epoch_created = current_epoch+1 (the user must wait one more epoch, because their unstake-delta will be execute in this epoch)
min_stake: u64extra_stake_delta_runs: u32can be set by validator-manager-auth to allow a second run of stake-delta to stake late stakers in the last minute of the epoch so we maximize user’s rewards
Implementations
Sourceimpl StakeSystem
impl StakeSystem
pub const STAKE_WITHDRAW_SEED: &'static [u8] = b"withdraw"
pub const STAKE_DEPOSIT_SEED: &'static [u8] = b"deposit"
pub fn bytes_for_list(count: u32, additional_record_space: u32) -> u32
pub fn stake_list_address(&self) -> &Pubkey
pub fn stake_count(&self) -> u32
pub fn stake_list_capacity( &self, stake_list_len: usize, ) -> Result<u32, ProgramError>
pub fn stake_record_size(&self) -> u32
pub fn get( &self, stake_list_data: &[u8], index: u32, ) -> Result<StakeRecord, ProgramError>
pub fn check_stake_list<'info>( &self, stake_list: &AccountInfo<'info>, ) -> ProgramResult